#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals, absolute_import

from .icalendar import Calendar
from .event import Event
from .__meta__ import (
    __title__,
    __version__,
    __author__,
    __license__,
    __copyright__,
)
